@@ -14,6 +14,8 @@ from django.conf import settings
 
 from tendenci.core.base.http import Http403
 from tendenci.core.theme.shortcuts import themed_response as render_to_response
+
+from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import has_perm
 from tendenci.core.event_logs.models import EventLog
 from tendenci.core.site_settings.utils import get_setting
@@ -23,6 +25,7 @@ from tendenci.apps.invoices.models import Invoice
 from tendenci.apps.invoices.forms import AdminNotesForm, AdminAdjustForm, InvoiceSearchForm
 
 
+@is_enabled('invoices')
 def view(request, id, guid=None, form_class=AdminNotesForm, template_name="invoices/view.html"):
     #if not id: return HttpResponseRedirect(reverse('invoice.search'))
     invoice = get_object_or_404(Invoice, pk=id)
@@ -90,6 +93,7 @@ def void_payment(request, id):
     return redirect(invoice)
 
 
+@is_enabled('discounts')
 @login_required
 def search(request, template_name="invoices/search.html"):
     query = u''
@@ -118,18 +122,11 @@ def search(request, template_name="invoices/search.html"):
         invoices = Invoice.objects.all()
         if bill_to_email:
             invoices = invoices.filter(bill_to_email=bill_to_email)
-
+    
     if invoice_type:
         content_type = ContentType.objects.filter(app_label=invoice_type)
         invoices = invoices.filter(object_type__in=content_type)
-        if invoice_type == 'memberships':
-            membership_content_type = ContentType.objects.get(app_label='memberships', model='appentry')
-            corporate_membership_content_type = ContentType.objects.get(app_label='corporate_memberships', model='corporatemembership')
-            invoices = invoices.filter(object_type__in=[membership_content_type.id, corporate_membership_content_type.id])
-        elif invoice_type == 'events':
-            event_content_type = ContentType.objects.get(app_label='events', model='registration')
-            invoices = invoices.filter(object_type=event_content_type.id)
-
+        if invoice_type == 'events':
             # Set event filters
             event_set = set()
             if event:
@@ -138,10 +135,7 @@ def search(request, template_name="invoices/search.html"):
                 event_set.add(event_id)
             if event or event_id:
                 invoices = invoices.filter(registration__event__pk__in=event_set)
-        elif invoice_type == 'jobs':
-            job_content_type = ContentType.objects.get(app_label='jobs', model='job')
-            invoices = invoices.filter(object_type=job_content_type.id)
-
+            
     if start_dt:
         invoices = invoices.filter(create_dt__gte=datetime.combine(start_dt, time.min))
      
@@ -208,7 +202,8 @@ def search_report(request, template_name="invoices/search.html"):
     return render_to_response(template_name, {'invoices': invoices, 'query': query},
         context_instance=RequestContext(request))
 
-    
+
+@is_enabled('discounts')
 def adjust(request, id, form_class=AdminAdjustForm, template_name="invoices/adjust.html"):
     #if not id: return HttpResponseRedirect(reverse('invoice.search'))
     invoice = get_object_or_404(Invoice, pk=id)
@@ -265,7 +260,8 @@ def adjust(request, id, form_class=AdminAdjustForm, template_name="invoices/adju
                                               'form':form}, 
         context_instance=RequestContext(request))
 
-    
+
+@is_enabled('discounts')
 def detail(request, id, template_name="invoices/detail.html"):
     invoice = get_object_or_404(Invoice, pk=id)
 
@@ -303,6 +299,7 @@ def detail(request, id, template_name="invoices/detail.html"):
                                               context_instance=RequestContext(request))
 
 
+@is_enabled('discounts')
 @login_required
 def export(request, template_name="invoices/export.html"):
     """Export Invoices"""
@@ -314,6 +311,7 @@ def export(request, template_name="invoices/export.html"):
         # initilize initial values
         file_name = "invoices.csv"
         fields = [
+            'id',
             'guid',
             'object_type',
             'title',
