@@ -338,7 +338,12 @@ def edit(request, id, form_class=ProfileForm, template_name="profiles/edit.html"
             profile = form.save(request, user_edit)
            
             if request.user.profile.is_superuser:
-                security_level = form.cleaned_data['security_level']
+                # superusers cannot demote themselves
+                if user_edit == request.user:
+                    security_level = 'superuser'
+                    messages.add_message(request, messages.INFO, _("You cannot convert yourself to \"%(role)s\" role.") % {'role' : form.cleaned_data['security_level']})
+                else:
+                    security_level = form.cleaned_data['security_level']
                 
                 if security_level == 'superuser':
                     user_edit.is_superuser = 1
@@ -446,24 +451,26 @@ def delete(request, id, template_name="profiles/delete.html"):
 
     return render_to_response(template_name, {'user_this':user, 'profile': profile}, 
         context_instance=RequestContext(request))
-    
+
+
 @login_required
 def edit_user_perms(request, id, form_class=UserPermissionForm, template_name="profiles/edit_perms.html"):
     user_edit = get_object_or_404(User, pk=id)
+
     try:
         profile = Profile.objects.get(user=user_edit)
     except Profile.DoesNotExist:
         profile = Profile.objects.create_profile(user=user_edit)
-   
+
     # for now, only admin can grant/remove permissions
-    if not request.user.profile.is_superuser: raise Http403
-    
+    if not request.user.profile.is_superuser:
+        raise Http403
+
     if request.method == "POST":
         form = form_class(request.POST, request.user, instance=user_edit)
     else:
         form = form_class(instance=user_edit)
     if form.is_valid():
-        user_edit.is_superuser = form.cleaned_data['is_superuser']
         user_edit.user_permissions = form.cleaned_data['user_permissions']
         user_edit.save()
 
@@ -1098,7 +1105,8 @@ def merge_process(request, sid):
                                     if model.objects.filter(**field_dict).exists():
                                         obj.delete()
                                     else:
-                                        obj.update(**{field.name: master.user}) 
+                                        setattr(obj, field.name, master.user)
+                                        obj.save()
                             else:
                                 if objs.exists():
                                     objs.update(**{field.name: master.user})
